/* config.h for MSVC builds.  This is just the config.h created by
 * configure. */

/* Name of package */
#define PACKAGE "chocolate-doom"

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "fraggle@gmail.com"

/* Define to the full name of this package. */
#define PACKAGE_NAME "Chocolate Doom"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "Chocolate Doom 1.6.0"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "chocolate-doom"

/* Define to the version of this package. */
#define PACKAGE_VERSION "1.6.0"

/* Change this when you create your awesome forked version */
#define PROGRAM_PREFIX "chocolate-"

/* Version number of package */
#define VERSION "1.6.0"

/* Define to 1 if your processor stores words with the most significant byte
   first (like Motorola and SPARC, unlike Intel and VAX). */
/* #undef WORDS_BIGENDIAN */

